@@ -1,5 +1,6 @@
 #include <cstdio>
 #include <cstdlib>
+#include <cstring>
 #include <string>
 #include <pbd/dirname.h>
 
@@ -8,7 +9,7 @@ char *
 PBD::dirname (const char *path)
 
 {
-	char *slash;
+	const char *slash;
 	size_t len;
 	char *ret;
 	
@@ -23,7 +24,7 @@ PBD::dirname (const char *path)
 	len = (size_t) (slash - path);
 	ret = (char *) malloc (sizeof (char) * (len + 1));
 
-	snprintf (ret, len, "%*s", len, path);
+	snprintf (ret, len, "%*s", (int)len, path);
 	return ret;
 }
 
