@@ -172,7 +172,7 @@ void ConfigPanel::init()
 	colsizer->Add (rowsizer, 0 , wxEXPAND|wxALL, 1);
 	
 	
-	wxFlexGridSizer * setsizer = new wxFlexGridSizer(-1, 2, 4, 4);
+	wxFlexGridSizer * setsizer = new wxFlexGridSizer(0, 2, 4, 4);
 
 
 	statText = new wxStaticText(this, -1, wxT("# Loops:"));
@@ -245,8 +245,8 @@ void ConfigPanel::init()
 	topsizer->Add (colsizer, 0, wxEXPAND|wxALL, 4);
 
 	
-	_parent->get_loop_control().LooperConnected.connect(slot (*this, &ConfigPanel::looper_connected));
-	_parent->get_loop_control().Disconnected.connect(slot (*this, &ConfigPanel::refresh_state));
+	_parent->get_loop_control().LooperConnected.connect(mem_fun (*this, &ConfigPanel::looper_connected));
+	_parent->get_loop_control().Disconnected.connect(mem_fun (*this, &ConfigPanel::refresh_state));
 	
 	refresh_state();
 	refresh_defaults();
