@@ -37,7 +37,7 @@ class MainPanel;
 class KeyboardTarget;
 	
 class ConfigPanel
-	: public wxPanel,  public SigC::Object
+	: public wxPanel,  public sigc::trackable
 {
   public:
 	
