@@ -50,7 +50,7 @@ class KeyboardTarget
 	virtual ~KeyboardTarget();
 
 	// first arg is key_release bool
-	typedef SigC::Slot1<void, bool> KeyAction;
+	typedef sigc::slot1<void, bool> KeyAction;
 
 	typedef std::vector<unsigned int> KeyState;
 
@@ -79,16 +79,16 @@ class KeyboardTarget
 	bool stop_learning (bool cancel=false);
 	bool is_learning() { return _learning; }
 	
-	static int add_action (string, KeyAction);
-	static int find_action (string, KeyAction&);
-	static int remove_action (string);
-	static void show_all_actions();
-	static void get_action_names (ActionNameList & nlist);
+	int add_action (string, KeyAction);
+	int find_action (string, KeyAction&);
+	int remove_action (string);
+	void show_all_actions();
+	void get_action_names (ActionNameList & nlist);
 	
 	
 	wxWindow * window() const { return _window; }
 
-	SigC::Signal0<void> LearningStopped;
+	sigc::signal0<void> LearningStopped;
 	
   protected:
 	typedef map<KeyState,KeyAction> KeyMap;
@@ -109,7 +109,7 @@ class KeyboardTarget
 	
   private:
 	typedef map<string,KeyAction> ActionMap; 
-	static ActionMap actions;
+	ActionMap actions;
 	string _name;
 	wxWindow * _window;
 
