@@ -281,6 +281,7 @@ void
 LoopControl::setup_param_map()
 {
 	state_map[LooperStateOff] = wxT("off");
+	state_map[LooperStateOffMuted] = wxT("off");
 	state_map[LooperStateWaitStart] = wxT("waiting start");
 	state_map[LooperStateRecording] = wxT("recording");
 	state_map[LooperStateWaitStop] = wxT("waiting stop");
@@ -317,12 +318,15 @@ LoopControl::connect()
 	// if the spawn_config host string is 127.0.0.1 or localhost, make our_url match it
 	if (_spawn_config.host == "127.0.0.1" || _spawn_config.host == "localhost") {
 		char tmpbuf[100];
-		snprintf (tmpbuf, sizeof(tmpbuf), "osc.udp://127.0.0.1:%d/", _our_port);
+		snprintf (tmpbuf, sizeof(tmpbuf), "osc.udp://localhost:%d/", _our_port);
 		_our_url = tmpbuf;
 		cerr << "Changing our url to be : " << _our_url << endl;
 	}
 
 	_pingack = false;
+
+	_registeredauto_loop_map.clear();
+	_registeredin_loop_map.clear();
 	
 	if (!_spawn_config.force_spawn) {
 		// send off a ping.  set a timer, if we don't have a response, we'll start our own locally
@@ -671,6 +675,11 @@ LoopControl::pingack_handler(const char *path, const char *types, lo_arg **argv,
 
 	cerr << "slgui: remote looper is at " << hosturl << " version=" << version << "   loopcount=" << loopcount << "  id=" << uid << endl;
 
+        if (loopcount < _registeredin_loop_map.size()) {
+                _registeredin_loop_map.erase(_registeredin_loop_map.find(loopcount), _registeredin_loop_map.end());
+                _registeredauto_loop_map.erase(_registeredauto_loop_map.find(loopcount), _registeredauto_loop_map.end());
+        }
+
 	char * remport = lo_url_get_port(hosturl.c_str());
 	wxString tmpstr = wxString::FromAscii(remport);
 	tmpstr.ToLong(&_spawn_config.port);
@@ -711,11 +720,13 @@ LoopControl::pingack_handler(const char *path, const char *types, lo_arg **argv,
 	}
 	_osc_addr = lo_address_new_from_url (hosturl.c_str());
 
-	if (_engine_id != 0 && _engine_id != uid) {
+	if (_engine_id != 0 && _engine_id != uid && uid != 0) {
 		cerr << "new engine ID pingacked us!, re-registering" << endl;
 		_pingack = false;
 	}
-	_engine_id = uid;
+        if (uid != 0) {
+                _engine_id = uid;
+        }
 
 	if (!_pingack) {
 		// register future configs with it once
@@ -748,7 +759,7 @@ LoopControl::alive_handler(const char *path, const char *types, lo_arg **argv, i
 	// s:hosturl  s:version  i:loopcount [i:id]
 	if (argc > 3) {
 		int uid = argv[3]->i;
-		if (uid != _engine_id) {
+		if (uid != _engine_id && uid != 0) {
 			cerr << "engine changed on us, redoing connections" << endl;
 			return pingack_handler(path, types, argv, argc, data);
 		}
@@ -1080,12 +1091,48 @@ LoopControl::save_midi_bindings(const wxString & filename)
 	lo_send(_osc_addr, "/save_midi_bindings", "ss", (const char *) filename.ToAscii(), "");
 }
 
+
+int
+LoopControl::register_all_in_new_thread(int number_of_loops)
+{
+
+	pthread_t register_thread;
+	get_spawn_config().num_loops = number_of_loops; //XXX why don't we have the right num_loops already?
+	return pthread_create (&register_thread, NULL, &LoopControl::_register_all, this);
+
+}
+
+void *
+LoopControl::_register_all (void *arg)
+{
+	//send all registrations pausing inbetween toavoid losing osc messages
+
+	LoopControl * lc = static_cast<LoopControl *>(arg);
+
+	lc->request_global_values ();
+
+	int num_of_loops = lc->get_spawn_config().num_loops;
+
+	for (int i = 0; i < num_of_loops; i++) {
+			lc->register_auto_updates(i);
+			lc->register_input_controls(i);
+			lc->request_all_values (i);
+#if wxCHECK_VERSION(2,5,3)
+		::wxMilliSleep(100);
+#else
+		::wxUsleep(100);
+#endif
+	}
+	return 0;
+}
+
 void
 LoopControl::register_auto_updates(int index, bool unreg)
 {
 	if (!_osc_addr) return;
 	char buf[30];
 
+
 	if (unreg) {
 		snprintf(buf, sizeof(buf), "/sl/%d/unregister_auto_update", index);
 		lo_send(_osc_addr, buf, "sss", "state", _our_url.c_str(), "/ctrl");
@@ -1103,6 +1150,12 @@ LoopControl::register_auto_updates(int index, bool unreg)
 		lo_send(_osc_addr, buf, "sss", "stretch_ratio", _our_url.c_str(), "/ctrl");
 		lo_send(_osc_addr, buf, "sss", "pitch_shift", _our_url.c_str(), "/ctrl");
 	} else {
+                if (_registeredauto_loop_map.find(index) != _registeredauto_loop_map.end()) {
+                        // already registered
+                        return;
+                }
+                
+
 		snprintf(buf, sizeof(buf), "/sl/%d/register_auto_update", index);
 		// send request for auto updates
 		lo_send(_osc_addr, buf, "siss", "state",     100, _our_url.c_str(), "/ctrl");
@@ -1119,6 +1172,8 @@ LoopControl::register_auto_updates(int index, bool unreg)
 		lo_send(_osc_addr, buf, "siss",  "is_soloed", 100, _our_url.c_str(), "/ctrl");
 		lo_send(_osc_addr, buf, "siss", "stretch_ratio", 100, _our_url.c_str(), "/ctrl");
 		lo_send(_osc_addr, buf, "siss", "pitch_shift", 100, _our_url.c_str(), "/ctrl");
+
+                _registeredauto_loop_map[index] = true;
 	}
 
 	
@@ -1131,6 +1186,16 @@ LoopControl::register_input_controls(int index, bool unreg)
 	if (!_osc_addr) return;
 	char buf[50];
 
+        if (_registeredin_loop_map.find(index) != _registeredin_loop_map.end()) {
+                // already registered
+                return;
+        }
+
+        if ((int)_params_val_map.size() <= index) {
+		_params_val_map.resize(index + 1);
+		_updated.resize(index + 1);
+        }
+
 	if ((int)_params_val_map.size() > index) {
 		_params_val_map[index].clear();
 		_updated[index].clear();
@@ -1178,6 +1243,10 @@ LoopControl::register_input_controls(int index, bool unreg)
 	lo_send(_osc_addr, buf, "sss", "pan_2", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "pan_3", _our_url.c_str(), "/ctrl");
 	lo_send(_osc_addr, buf, "sss", "pan_4", _our_url.c_str(), "/ctrl");
+
+        // cerr << "SENT REGISTERS FOR ALL index: " << index << endl;
+
+        _registeredin_loop_map[index] = true;
 }
 
 void
@@ -1534,6 +1603,7 @@ LoopControl::post_remove_loop()
 	if (lo_send(_osc_addr, "/loop_del", "i", index) == -1) {
 		return false;
 	}
+
 	return true;
 }
 
